import { aws_iam as iam, aws_autoscaling as autoscaling, aws_ec2 as ec2, aws_ssm as ssm } from 'aws-cdk-lib';
/**
 * Properties for a fck-nat instance
 */
export interface FckNatInstanceProps {
    /**
     * The machine image (AMI) to use
     *
     * By default, will do an AMI lookup for the latest fck-nat instance image.
     *
     * If you have a specific AMI ID you want to use, pass a `GenericLinuxImage`. For example:
     *
     * ```ts
     * FckNatInstanceProvider({
     *   instanceType: new ec2.InstanceType('t3.micro'),
     *   machineImage: new LookupMachineImage({
     *     name: 'fck-nat-al2023-*-arm64-ebs',
     *     owners: ['568608671756'],
     *   })
     * })
     * ```
     *
     * @default - Latest fck-nat instance image
     */
    readonly machineImage?: ec2.IMachineImage;
    /**
     * Instance type of the fck-nat instance
     */
    readonly instanceType: ec2.InstanceType;
    /**
     * Name of SSH keypair to grant access to instance. Setting this value will not automatically update security groups,
     * that must be done separately.
     *
     * @default - No SSH access will be possible.
     * @deprecated - CDK has deprecated the `keyName` parameter, use `keyPair` instead.
     */
    readonly keyName?: string;
    /**
     * SSH keypair to attach to instances. Setting this value will not automatically update security groups, that must be
     * done separately.
     *
     * @default - No SSH access will be possible.
     */
    readonly keyPair?: ec2.IKeyPair;
    /**
     * Security Group for fck-nat instances
     *
     * @default - A new security group will be created
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * A list of EIP allocation IDs which can be attached to NAT instances. The number of allocations supplied must be
     * greater than or equal to the number of egress subnets in your VPC.
     */
    readonly eipPool?: string[];
    /**
     * Add necessary role permissions for SSM automatically
     *
     * @default - SSM is enabled
     */
    readonly enableSsm?: boolean;
    /**
     * Add necessary role permissions and configuration for supplementary CloudWatch metrics. ENABLING THIS FEATURE WILL
     * INCUR ADDITIONAL COSTS! See https://fck-nat.dev/develop/features/#metrics for more details.
     *
     * @default - Additional Cloudwatch metrics are disabled
     */
    readonly enableCloudWatch?: boolean;
    /**
     * Optionally override the base Cloudwatch metric configuration found at https://fck-nat.dev/develop/features/#metrics
     *
     * If you wish to override the default parameter name, the default configuration contents are stored on the
     * `FckNatInstanceProvider.DEFAULT_CLOUDWATCH_CONFIG` constant
     *
     * @default - If Cloudwatch metrics are enabled, a default configuration will be used.
     */
    readonly cloudWatchConfigParam?: ssm.IStringParameter;
    /**
     * Optionally add commands to the user data of the instance.
     *
     * @default - No additional user commands are added.
     */
    readonly userData?: string[];
    /**
     *
     * Configures the auto-scaling group update policy for the fck-nat instances.
     * This will update the existing instance and new instances with the latest ASG configuration.
     * See: https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_autoscaling.UpdatePolicy.html
     * @default -  No update policy is applied.
     */
    readonly asgUpdatePolicy?: autoscaling.UpdatePolicy;
}
export declare class FckNatInstanceProvider extends ec2.NatProvider implements ec2.IConnectable {
    private readonly props;
    /**
     * The AMI name used internally when calling `LookupMachineImage`. Can be referenced if you wish to do AMI lookups
     * externally.
     */
    static readonly AMI_NAME = "fck-nat-al2023-*-arm64-ebs";
    /**
     * The AMI owner used internally when calling `LookupMachineImage`. Can be referenced if you wish to do AMI lookups
     * externally.
     */
    static readonly AMI_OWNER = "568608671756";
    /**
     * The default CloudWatch config used when additional CloudWatch metric reporting is enabled.
     */
    static readonly DEFAULT_CLOUDWATCH_CONFIG: any;
    private gateways;
    private _securityGroup?;
    private _connections?;
    private _role?;
    private _autoScalingGroups?;
    constructor(props: FckNatInstanceProps);
    configureNat(options: ec2.ConfigureNatOptions): void;
    configureSubnet(subnet: ec2.PrivateSubnet): void;
    /**
     * The instance role attached with the NAT instances.
     */
    get role(): iam.Role;
    /**
     * The ASGs (Auto Scaling Groups) managing the NAT instances. These can be retrieved to get metrics and
     */
    get autoScalingGroups(): autoscaling.AutoScalingGroup[];
    /**
     * The Security Group associated with the NAT instances
     */
    get securityGroup(): ec2.ISecurityGroup;
    /**
     * Manage the Security Groups associated with the NAT instances
     */
    get connections(): ec2.Connections;
    get configuredGateways(): ec2.GatewayConfig[];
}
